@@ -2,6 +2,7 @@
 library(bellreg)
 
 # ML approach:
+data(faults)
 mle <- bellreg(nf ~ lroll, data = faults, approach = "mle")
 summary(mle)
 coef(mle)
@@ -9,5 +10,5 @@ vcov(mle)
 confint(mle)
 
 # Bayesian approach:
-bayes <- bellreg(nf ~ lroll, data = faults, approach = "bayes")
+bayes <- bellreg(nf ~ lroll, data = faults, approach = "bayes", refresh = FALSE)
 summary(bayes)
